{***************************************************************
 *
 * Unit Name : Main
 * Purpose   : Image Converter
 * Author    : Eugen Mihailescu
 * Company   : EM Quicksoft Romania SRL
 * Copyright : 1998,2002  All rights reserved.
 * Web Site  : http://www.em-quicksoft.com
 * Support   : support@em-quicksoft.com
 * History   : 03/17/2000
 *
 ****************************************************************}

{x$DEFINE ABOUTBOX}

Unit Main;

Interface

Uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  StdCtrls,
  Mask,
  ComCtrls,
  Buttons,
  ExtCtrls,
  ExtDlgs,
  IniFiles,
  jpeg,
  clipbrd,
  GIFImage,
  CServGIF;

Type
  TImgType = (itBMP, itEMF, itGIF, itICO, itJPG, itWMF);

  TfrmImgConv = Class(TForm)
    pnlMain: TPanel;
    lblSrc: TLabel;
    lblDest: TLabel;
    edtSrc: TEdit;
    edtDest: TEdit;
    cmbConvertTo: TComboBox;
    lblConvertTo: TLabel;
    spbSrc: TSpeedButton;
    spbDest: TSpeedButton;
    pnlCommands: TPanel;
    btnExit: TButton;
    btnHelp: TButton;
    btnConvert: TButton;
    ColorDialog: TColorDialog;
    OpenPictureDialog: TOpenPictureDialog;
    SavePictureDialog: TSavePictureDialog;
    Notebook1: TNotebook;
    pnlCompression: TPanel;
    lblCompression: TLabel;
    trkCompression: TTrackBar;
    mskPercent: TMaskEdit;
    pnlTransparent: TPanel;
    chkTransparent: TCheckBox;
    pnlColor: TPanel;
    edtColor: TEdit;
    CheckBox1: TCheckBox;
    pnlIcon: TPanel;
    RadioGroup1: TRadioGroup;
    btnOption: TButton;
    pnlOptions: TPanel;
    CheckBox2: TCheckBox;
    Procedure spbSrcClick(Sender: TObject);
    Procedure spbDestClick(Sender: TObject);
    Procedure btnExitClick(Sender: TObject);
    Procedure pnlColorClick(Sender: TObject);
    Procedure trkCompressionChange(Sender: TObject);
    Procedure mskPercentChange(Sender: TObject);
    Procedure FormCreate(Sender: TObject);
    Procedure cmbConvertToChange(Sender: TObject);
    Procedure edtSrcChange(Sender: TObject);
    Procedure edtDestChange(Sender: TObject);
    Procedure edtSrcExit(Sender: TObject);
    Procedure btnOptionClick(Sender: TObject);
    Procedure btnConvertClick(Sender: TObject);
    Procedure FormClose(Sender: TObject; Var Action: TCloseAction);
  private
    Extension: String;
    Options: Boolean;
    Procedure InitSettings;
    Procedure SetCtrlState;
    Procedure SaveSettings;
    Procedure LoadSettings;
    Procedure Convert(FileName: String; filetype: TImgType);
  public
    { Public declarations }
  End;

Var
  frmImgConv        : TfrmImgConv;

Implementation

{$R *.DFM}
//******************* TfrmImgConv.SaveSettings *************************

Procedure TfrmImgConv.SaveSettings;
Var
  F                 : TIniFile;
Begin
  F := TIniFile.Create(ExtractFilePath(Application.ExeName) + 'Strings.ini');
  Try
    F.WriteString('Path', 'Source', edtsrc.Text);
    F.WriteString('Path', 'Destination', edtdest.Text);
    F.WriteInteger('Path', 'FileType', cmbconvertto.ItemIndex);
  Finally
    F.Free;
  End;
End;
//******************* TfrmImgConv.LoadSettings *************************

Procedure TfrmImgConv.LoadSettings;
Var
  F                 : TIniFile;
Begin
  F := TIniFile.Create(ExtractFilePath(Application.ExeName) + 'Strings.ini');
  Try
    edtsrc.Text := F.ReadString('Path', 'Source', '');
    edtdest.Text := F.ReadString('Path', 'Destination', '');
    cmbconvertto.ItemIndex := F.ReadInteger('Path', 'FileType', 0);
  Finally
    F.Free;
  End;
End;
//******************* TfrmImgConv.spbSrcClick *************************

Procedure TfrmImgConv.spbSrcClick(Sender: TObject);
Begin
  If OpenPictureDialog.Execute Then
    edtsrc.Text := OpenPictureDialog.FileName;
End;
//******************* TfrmImgConv.spbDestClick *************************

Procedure TfrmImgConv.spbDestClick(Sender: TObject);
Var
  L                 : TStringList;
Begin
  L := TStringList.Create;
  Try
    L.CommaText := SavePictureDialog.Filter;
    If SavePictureDialog.Execute Then
      edtdest.Text := SavePictureDialog.FileName + '.' + Extension;
  Finally
    L.Free;
  End;
End;
//******************* TfrmImgConv.btnExitClick *************************

Procedure TfrmImgConv.btnExitClick(Sender: TObject);
Begin
  Close;
End;
//******************* TfrmImgConv.pnlColorClick *************************

Procedure TfrmImgConv.pnlColorClick(Sender: TObject);
Begin
  If Not chkTransparent.Checked Then Exit;
  If ColorDialog.Execute Then
    pnlColor.Color := ColorDialog.Color;
  edtColor.Text := '$' + IntToHex(pnlColor.Color, 8);
End;
//******************* TfrmImgConv.trkCompressionChange *************************

Procedure TfrmImgConv.trkCompressionChange(Sender: TObject);
Begin
  mskPercent.Text := IntToStr(trkCompression.Position);
End;
//******************* TfrmImgConv.mskPercentChange *************************

Procedure TfrmImgConv.mskPercentChange(Sender: TObject);
Var
  S                 : String;
Begin
  Try
    S := StringReplace(StringReplace(mskPercent.Text, ' ', '', [rfReplaceAll]), '%', '', [rfReplaceAll]);
    trkCompression.Position := StrToInt(S);
  Except
    trkCompression.Position := 0;
  End;
End;
//******************* TfrmImgConv.InitSettings *************************

Procedure TfrmImgConv.InitSettings;
Begin
  Height := pnlMain.Height + pnlCommands.Height + 40;
  {$IFDEF ABOUTBOX}
  MessageDlg('Image Converter'#13'freeware version 1.0'#13#13'Author: Eugen Mihailescu'#13'Last Update: 17-Mar-00'#13#13' 2000 by EM Quicksoft Romania'#13'All rights reserved', mtInformation, [mbOK], 0);
  {$ENDIF}
  LoadSettings;
End;
//******************* TfrmImgConv.FormCreate *************************

Procedure TfrmImgConv.FormCreate(Sender: TObject);
Begin
  InitSettings;
  SetCtrlState;
End;
//******************* TfrmImgConv.SetCtrlState *************************

Procedure TfrmImgConv.SetCtrlState;
Begin
  btnConvert.Enabled := fileexists(edtsrc.Text) And (edtdest.Text <> '') And (cmbConvertTo.ItemIndex >= 0);
End;
//******************* TfrmImgConv.cmbConvertToChange *************************

Procedure TfrmImgConv.cmbConvertToChange(Sender: TObject);
Var
  S                 : String;
Begin
  Extension := cmbConvertTo.Items.Strings[cmbconvertto.ItemIndex];
  If extractfileext(edtdest.Text) <> '' Then
    edtdest.Text := StringReplace(edtdest.Text, extractfileext(edtdest.Text), '.' + extension, [])
  Else
    If edtdest.Text <> '' Then
    edtdest.Text := edtdest.Text + '.' + extension;
  If (extension = 'JPG') Or (extension = 'GIF') Or (extension = 'ICO') Then
    Begin
      Height := pnlMain.Height + pnlCommands.Height + 40;
      Height := Height + Notebook1.Height + 8;
      Notebook1.Visible := True;
      If (extension = 'JPG') Then
        Notebook1.PageIndex := 0
      Else
        If (extension = 'GIF') Then
        Notebook1.PageIndex := 1
      Else
        If (extension = 'ICO') Then
        Notebook1.PageIndex := 2;
    End
  Else
    Begin
      Height := pnlMain.Height + pnlCommands.Height + 40;
      Notebook1.Visible := False;
    End;
  setctrlstate;
End;
//******************* TfrmImgConv.edtSrcChange *************************

Procedure TfrmImgConv.edtSrcChange(Sender: TObject);
Begin
  setctrlstate;
End;
//******************* TfrmImgConv.edtDestChange *************************

Procedure TfrmImgConv.edtDestChange(Sender: TObject);
Begin
  setctrlstate;
End;
//******************* TfrmImgConv.edtSrcExit *************************

Procedure TfrmImgConv.edtSrcExit(Sender: TObject);
Begin
  If Not fileexists(edtsrc.Text) Then
    MessageDlg(Format('File %s not exists. Convertion not allowed.', [edtsrc.Text]), mtWarning, [mbOK], 0);
End;
//******************* TfrmImgConv.btnOptionClick *************************

Procedure TfrmImgConv.btnOptionClick(Sender: TObject);
Begin
  Options := Not Options;
  If Options Then
    Begin
      btnOption.Caption := '<< Options';
      Notebook1.PageIndex := 3;
      Height := pnlMain.Height + pnlCommands.Height + 40;
      Height := Height + Notebook1.Height + 8;
      Notebook1.Visible := True;
    End
  Else
    Begin
      btnOption.Caption := 'Options >>';
      Notebook1.PageIndex := 3;
      Height := pnlMain.Height + pnlCommands.Height + 40;
      Notebook1.Visible := False;
      cmbConvertToChange(Self);
    End;
End;
//******************* TfrmImgConv.Convert *************************

Procedure TfrmImgConv.Convert(FileName: String; filetype: TImgType);
Var
  vSrc, vDst        : TImage;
  vClpbrd           : TClipboard;

  FICO              : TIcon;
  FBMP              : TBitmap;
  FGIF              : TGIFImage;
  FWMF              : TMetaFile;
  FJPG              : TJPEGImage;

  AFormat           : Word;
  AData             : THandle;
  APalette          : HPalette;
Begin
  If Not fileexists(FileName) Then Exit;
  vSrc := TImage.Create(Self);
  vDst := TImage.Create(Self);
  vClpbrd := TClipboard.Create;

  Try
    vSrc.Picture.LoadFromFile(FileName);
    vSrc.Picture.SaveToClipboardFormat(aformat, AData, apalette);
    vClpbrd.SetAsHandle(AFormat, AData);

    Case filetype Of
      itBMP: FBMP := TBitmap.Create;
      itICO: FICO := ticon.Create;
      itJPG: FJPG := TJPEGImage.Create;
      itWMF: FWMF := tmetafile.Create;
      itGIF: FGIF := tgifimage.Create;
    End;

    Try
    Finally
      Case filetype Of
        itBMP: FBMP.Free;
        itICO: FICO.Free;
        itJPG: FJPG.Free;
        itWMF: FWMF.Free;
        itGIF: FGIF.Free;
      End;
    End;

  Finally
    vclpbrd.Free;
    vSrc.Free;
    vDst.Free;
  End;
End;
//******************* TfrmImgConv.btnConvertClick *************************

Procedure TfrmImgConv.btnConvertClick(Sender: TObject);
Begin
  convert(edtsrc.Text, TImgType(cmbConvertTo.ItemIndex));
End;
//******************* TfrmImgConv.FormClose *************************

Procedure TfrmImgConv.FormClose(Sender: TObject; Var Action: TCloseAction);
Begin
  SaveSettings;
End;

Initialization

  gifRegisterGraphicClass('GIF', TGIFImage);

Finalization

  gifUnRegisterGraphicClass(TGIFImage);
End.

